Struct ImplicitCenteredMomentumConvection
pub struct ImplicitCenteredMomentumConvection { /* private fields */ }Description
Endpoint-centered conservative momentum convection for one velocity Field.
The actual face volume flux is owned by the collocated coupling below. This transformation requires momentum convection to consume that unique flux; it cannot independently interpolate a second velocity flux.
Implementations
impl ImplicitCenteredMomentumConvection
impl ImplicitCenteredMomentumConvection
pub const fn new(
relation: Id<Relation>,
velocity: Id<Field>,
) -> ImplicitCenteredMomentumConvection
pub const fn new( relation: Id<Relation>, velocity: Id<Field>, ) -> ImplicitCenteredMomentumConvection
Select endpoint-centered convection for one exact momentum/velocity pair.
pub const fn relation(self) -> Id<Relation>
pub const fn relation(self) -> Id<Relation>
Exact conservative momentum Relation.