Struct StorageChunkV1
pub struct StorageChunkV1 { /* private fields */ }Description
Independently content-addressed raw canonical-byte chunk.
This is a storage object, not logical Field identity. It intentionally has no path, locator, codec, compression, or container metadata.
Implementations
impl StorageChunkV1
impl StorageChunkV1
pub fn from_bytes(bytes: Vec<u8>) -> StorageChunkV1
pub fn from_bytes(bytes: Vec<u8>) -> StorageChunkV1
Content-address arbitrary raw storage bytes in the closed v1 domain.
pub const fn digest(&self) -> &StorageChunkSha256V1
pub const fn digest(&self) -> &StorageChunkSha256V1
Raw SHA-256 byte identity in the storage-chunk digest type.