Struct TrajectoryDecoderLimits
pub struct TrajectoryDecoderLimits {
pub json: JsonDecoderLimits,
pub max_spatial_state_fields: usize,
pub max_remesh_trajectory_segments: usize,
pub max_remesh_trajectory_states: usize,
pub max_trajectory_segment_states: usize,
pub max_trajectory_segments: usize,
pub max_trajectory_states: usize,
pub max_dataset_view_fields: usize,
}Description
Semantic work budgets shared by immutable trajectory and derived-view artifacts.
Fields
json: JsonDecoderLimitsCommon JSON syntax admission.
max_spatial_state_fields: usizeMaximum Field references summarized by one trajectory state.
max_remesh_trajectory_segments: usizeMaximum v3 segments in one remeshing-aware trajectory root.
max_remesh_trajectory_states: usizeMaximum target states summarized by one remeshing-aware trajectory root.
max_trajectory_segment_states: usizeMaximum state references in one immutable trajectory segment.
max_trajectory_segments: usizeMaximum immutable segments referenced by one trajectory root.
max_trajectory_states: usizeMaximum accepted states summarized by one complete trajectory root.
max_dataset_view_fields: usizeMaximum Field selections in one derived Dataset view.