Struct ConformingTraceQuotient
pub struct ConformingTraceQuotient { /* private fields */ }Description
Equality quotient of two conforming Field traces selected by one Connection.
This is a numerical identity choice, not a physical interface definition. The semantic lowerer remains responsible for proving conserving Connection semantics and compatible Field shape, support, units, frame, and orientation.
Implementations
impl ConformingTraceQuotient
impl ConformingTraceQuotient
pub fn new(
connection: Id<Connection>,
first: TraceFieldEndpoint,
second: TraceFieldEndpoint,
) -> Result<ConformingTraceQuotient, Diagnostic>
pub fn new( connection: Id<Connection>, first: TraceFieldEndpoint, second: TraceFieldEndpoint, ) -> Result<ConformingTraceQuotient, Diagnostic>
Signature links:newIdConnectionTraceFieldEndpointTraceFieldEndpointResultConformingTraceQuotientDiagnostic
Construct a canonically ordered cross-Domain trace quotient.
Errors
Returns EQ0807 when both endpoints belong to the same Domain.
pub const fn connection(self) -> Id<Connection>
pub const fn connection(self) -> Id<Connection>
Exact conserving Connection selected by the semantic lowerer.
pub const fn endpoints(self) -> [TraceFieldEndpoint; 2]
pub const fn endpoints(self) -> [TraceFieldEndpoint; 2]
Canonically ordered trace endpoints.