Struct IndexedAssemblyWork
pub struct IndexedAssemblyWork<F> { /* private fields */ }Description
Ergonomic AssemblyWork backed by one immutable indexed closure.
Implementations
impl<F> IndexedAssemblyWork<F>
impl<F> IndexedAssemblyWork<F>
pub const fn new(packet_count: usize, evaluate: F) -> IndexedAssemblyWork<F>
pub const fn new(packet_count: usize, evaluate: F) -> IndexedAssemblyWork<F>
Bind a stable packet count to an indexed evaluator.
pub const fn for_packet_set(
packet_set: AssemblyPacketSetIdentityV1,
packet_count: usize,
evaluate: F,
) -> IndexedAssemblyWork<F>
pub const fn for_packet_set( packet_set: AssemblyPacketSetIdentityV1, packet_count: usize, evaluate: F, ) -> IndexedAssemblyWork<F>
Bind an authenticated ordered packet set to an indexed evaluator.