Enum RemeshProjectionExecutionModeV1
pub enum RemeshProjectionExecutionModeV1 {
PrescribedExactly,
Solved,
}Description
Closed execution mode of one projection action.
Variants
PrescribedExactly
Boundary data prescribes every target degree of freedom exactly.
Solved
One or more component systems were solved and fully reported.