Enum ExprNode
#[non_exhaustive]pub enum ExprNode {
Show 17 variants
Constant(DynQuantity),
Symbol(SymbolRef),
Neg(ExprId),
Add(ExprId, ExprId),
Sub(ExprId, ExprId),
Mul(ExprId, ExprId),
Div(ExprId, ExprId),
PowI(ExprId, i32),
SpatialCoordinate(usize),
UnaryMath(UnaryMathFunction, ExprId),
Gradient(ExprId),
Divergence(ExprId),
SymmetricPart(ExprId),
IsotropicLift(ExprId),
Trace(ExprId),
NormalComponent(ExprId),
PureOperatorApplication(PureOperatorApplication),
}Description
One node in a topologically ordered residual-expression DAG.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Constant(DynQuantity)
Dimensioned scalar constant.
Symbol(SymbolRef)
Kernel symbol reference.
Neg(ExprId)
Unary negation.
Add(ExprId, ExprId)
Addition.
Sub(ExprId, ExprId)
Subtraction.
Mul(ExprId, ExprId)
Multiplication.
Div(ExprId, ExprId)
Division.
PowI(ExprId, i32)
Integer power.
SpatialCoordinate(usize)
One physical Cartesian coordinate selected by zero-based axis. The owning Relation’s Domain supplies support and validates the axis.
UnaryMath(UnaryMathFunction, ExprId)
Apply one dimension-aware unary mathematical function.
Gradient(ExprId)
Physical-space gradient. The operand’s continuous Domain determines the appended spatial axis.
Divergence(ExprId)
Physical-space divergence, contracting the final spatial axis.
SymmetricPart(ExprId)
Symmetric part of a square Cartesian rank-two tensor.
IsotropicLift(ExprId)
Lift a supported invariant scalar to its isotropic Cartesian tensor.
Trace(ExprId)
Restriction of a parent-domain expression to the boundary Domain on which the owning Relation is scoped.
NormalComponent(ExprId)
Outward-normal component on the boundary Domain on which the owning Relation is scoped.
PureOperatorApplication(PureOperatorApplication)
Apply one expression-local, content-addressed pure definition.