Struct ModelDecoderLimits
pub struct ModelDecoderLimits {Show 15 fields
pub json: JsonDecoderLimits,
pub max_nodes: usize,
pub max_edges: usize,
pub max_expression_nodes: usize,
pub max_expression_roots: usize,
pub max_pure_operator_definitions: usize,
pub max_pure_operator_formals: usize,
pub max_pure_operator_calculus_nodes: usize,
pub max_pure_operator_application_arguments: usize,
pub max_model_view_members: usize,
pub max_model_boundary: usize,
pub max_value_shape_rank: usize,
pub max_value_shape_components: usize,
pub max_transaction_ops: usize,
pub max_transaction_preconditions: usize,
}Description
Semantic work budgets shared by the current Model and Model transaction.
Fields
json: JsonDecoderLimitsCommon JSON syntax admission.
max_nodes: usizeMaximum Semantic Kernel nodes in one Model envelope.
max_edges: usizeMaximum graph edges in one Model envelope.
max_expression_nodes: usizeMaximum expression nodes summed across one Model or transaction.
max_expression_roots: usizeMaximum expression roots summed across one Model or transaction.
max_pure_operator_definitions: usizeMaximum pure-operator definitions summed across expressions.
max_pure_operator_formals: usizeMaximum pure-operator formals summed across definitions.
max_pure_operator_calculus_nodes: usizeMaximum exact component-calculus nodes summed across definitions.
max_pure_operator_application_arguments: usizeMaximum ordered arguments summed across pure-operator applications.
max_model_view_members: usizeMaximum Semantic Model members.
max_model_boundary: usizeMaximum model-root boundary Ports.
max_value_shape_rank: usizeMaximum rank of one exact Semantic Model value shape.
max_value_shape_components: usizeMaximum checked scalar components in one Semantic Model value shape.
max_transaction_ops: usizeMaximum ordered operations in one Model transaction.
max_transaction_preconditions: usizeMaximum atomic preconditions in one Model transaction.