Type Alias SolverView
pub type SolverView = NamedSubgraph<Solver>;Description
The semantic relation scope to which a realization SolverPlan applies.
Aliased Type
pub struct SolverView { /* private fields */ }pub type SolverView = NamedSubgraph<Solver>;The semantic relation scope to which a realization SolverPlan applies.
pub struct SolverView { /* private fields */ }