Struct PortDef
pub struct PortDef { /* private fields */ }Description
Typed scalar Port definition.
Implementations
impl PortDef
impl PortDef
pub const fn signal(
id: Id<Port>,
direction: SignalDirection,
dimension: DimExponents,
) -> PortDef
pub const fn signal( id: Id<Port>, direction: SignalDirection, dimension: DimExponents, ) -> PortDef
Define a causal signal Port.
pub const fn conserving_marker(id: Id<Port>, dimension: DimExponents) -> PortDef
pub const fn conserving_marker(id: Id<Port>, dimension: DimExponents) -> PortDef
Preserve one structural-only v1 conserving Port marker.
pub const fn scalar_physical(id: Id<Port>, domain: Id<Domain>) -> PortDef
pub const fn scalar_physical(id: Id<Port>, domain: Id<Domain>) -> PortDef
Define a scalar conserving Port with nominal Domain identity.
pub const fn boundary_physical(
id: Id<Port>,
connector: Id<Domain>,
boundary: Id<Domain>,
) -> PortDef
pub const fn boundary_physical( id: Id<Port>, connector: Id<Domain>, boundary: Id<Domain>, ) -> PortDef
Define one field-valued physical Port on an exact boundary Domain.
pub const fn signal_contract(&self) -> Option<(SignalDirection, DimExponents)>
pub const fn signal_contract(&self) -> Option<(SignalDirection, DimExponents)>
Signal direction and scalar dimension, if this is a signal Port.
pub const fn marker_dimension(&self) -> Option<DimExponents>
pub const fn marker_dimension(&self) -> Option<DimExponents>
Structural marker dimension, if this is a v1 conserving marker.
pub const fn physical_domain(&self) -> Option<Id<Domain>>
pub const fn physical_domain(&self) -> Option<Id<Domain>>
Nominal physical Domain, if this is a scalar physical Port.