Struct ResolvedAlias
pub struct ResolvedAlias { /* private fields */ }Description
One direct source alias from a declaring package to an exact target.
Implementations
impl ResolvedAlias
impl ResolvedAlias
pub fn new(
declaring: CompilationNamespaceId,
alias: impl Into<String>,
target: CompilationNamespaceId,
) -> ResolvedAlias
pub fn new( declaring: CompilationNamespaceId, alias: impl Into<String>, target: CompilationNamespaceId, ) -> ResolvedAlias
Construct one direct alias. Alias spelling is validated during joint analysis so all input errors are reported together.
pub const fn declaring(&self) -> &CompilationNamespaceId
pub const fn declaring(&self) -> &CompilationNamespaceId
Package in whose source the alias may be used.
pub fn alias(&self) -> &str
pub fn alias(&self) -> &str
Exact source identifier used as the first path segment.
pub const fn target(&self) -> &CompilationNamespaceId
pub const fn target(&self) -> &CompilationNamespaceId
Exact target package namespace.