Enum ActivationKind
#[non_exhaustive]pub enum ActivationKind {
Continuous,
Periodic,
Event {
guard: ExprDag,
direction: EventDirection,
},
Guard {
guard: ExprDag,
},
}Description
Activation semantics independent of execution scheduling.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Continuous
Relation is active throughout continuous model time.
Periodic
Relation activates at ticks of its ClockedBy ClockDomain edge.
Event
Relation activates on a zero crossing of the guard expression.
Fields

direction: EventDirectionCrossing direction.
Guard
Relation is active while a scalar guard is positive.