Function symmetric_part
pub fn symmetric_part<I>(
operand: &ExpressionType<I>,
) -> Result<ExpressionType<I>, TypeViolation<I>>where
I: Clone,Description
Type the symmetric part of an exact square Cartesian tensor.
pub fn symmetric_part<I>(
operand: &ExpressionType<I>,
) -> Result<ExpressionType<I>, TypeViolation<I>>where
I: Clone,Type the symmetric part of an exact square Cartesian tensor.