Enum PhysicalUnknown
pub enum PhysicalUnknown {
Across(Id<Port>),
Through(Id<Port>),
}Description
One canonical unknown slot in a scalar physical subsystem.
Variants
Across(Id<Port>)
Across variable of a Port.
Through(Id<Port>)
Through variable, positive from the junction into the owning Relation.
Implementations
impl PhysicalUnknown
impl PhysicalUnknown