Struct CanonicalGeometryLimits
pub struct CanonicalGeometryLimits {
pub max_bytes: usize,
pub max_vertices: usize,
pub max_faces: usize,
pub max_loop_indices: usize,
pub max_entity_sets: usize,
pub max_entity_set_members: usize,
}Description
Work budgets for decoding one canonical authored planar geometry.
Fields
max_bytes: usizeMaximum encoded bytes accepted by the geometry decoder.
max_vertices: usizeMaximum vertices in one geometry.
max_faces: usizeMaximum planar faces in one geometry.
max_loop_indices: usizeMaximum vertex indices across all outer and hole loops.
max_entity_sets: usizeMaximum named entity sets.
max_entity_set_members: usizeMaximum members across all named entity sets.