Enum LinearSolver
pub enum LinearSolver {
ConjugateGradient,
MinimumResidual,
BiConjugateGradientStabilized,
SparseLu,
}Description
Linear algorithm selected independently from model meaning.
Variants
ConjugateGradient
Conjugate gradients for an asserted symmetric positive-definite operator.
MinimumResidual
Minimum residual iteration for a symmetric definite or indefinite operator.
BiConjugateGradientStabilized
Bi-conjugate gradient stabilized for a square general operator.
SparseLu
Partial-pivot sparse LU for an explicitly captured square operator.
Implementations
impl LinearSolver
impl LinearSolver
pub const fn accepts(self, properties: LinearOperatorProperties) -> bool
pub const fn accepts(self, properties: LinearOperatorProperties) -> bool
Whether this algorithm is mathematically admissible for an asserted operator class.
This is independent of whether a particular backend implements the requested scalar, preconditioner, or reduction tuple.