Enum InitialConditionPolicy
pub enum InitialConditionPolicy {
Provided,
SolveConsistent,
}Description
Meaning of the data supplied at the initial model time.
Variants
Provided
The supplied state, and derivative when present, are already accepted.
SolveConsistent
The supplied state/derivative data are guesses for a consistency solve.