Type Alias ObjectiveView
pub type ObjectiveView = NamedSubgraph<Objective>;Description
An optimization objective expressed by one or more Relations.
Aliased Type
pub struct ObjectiveView { /* private fields */ }pub type ObjectiveView = NamedSubgraph<Objective>;An optimization objective expressed by one or more Relations.
pub struct ObjectiveView { /* private fields */ }